{%- if filetype_loop == 0 %}Slot,Part,Description,PID,Serial Number,Virtual ID
{%-     for slot in to_parse_inventory %}
{%-         for part in to_parse_inventory[slot] %}
{%-             for part_number in to_parse_inventory[slot][part] %}
{{ slot }},{{ part_number }},{{ to_parse_inventory[slot][part][part_number].descr }},{{ to_parse_inventory[slot][part][part_number].pid }},{{ to_parse_inventory[slot][part][part_number].sn }},{{ to_parse_inventory[slot][part][part_number].vid }}
{%-             endfor %}
{%-         endfor %}
{%-     endfor %}
{%- else %}
{%-     if filetype_loop == 1 %}
# Show Inventory
| Slot | Part | Description | PID | Serial Number | Virtual ID |
| ---- | ---- | ----------- | --- | ------------- | ---------- |
{%-         for slot in to_parse_inventory %}
{%-             for part in to_parse_inventory[slot] %}
{%-                 for part_number in to_parse_inventory[slot][part] %}
| {{ slot }} | {{ part_number }} | {{ to_parse_inventory[slot][part][part_number].descr }} | {{ to_parse_inventory[slot][part][part_number].pid }} | {{ to_parse_inventory[slot][part][part_number].sn }} | {{ to_parse_inventory[slot][part][part_number].vid }} |
{%-                 endfor %}
{%-             endfor %}
{%-         endfor %}
{%-     else %}
{%-         if filetype_loop == 2 %}
<html>
<head>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.4/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/dataTables.buttons.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.1.3/jszip.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.html5.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.print.min.js"></script>
    <script src="https://cdn.datatables.net/colreorder/1.5.4/js/dataTables.colReorder.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.colVis.min.js"></script>
    <script src="https://cdn.datatables.net/keytable/2.6.4/js/dataTables.keyTable.min.js"></script>
    <script src="https://cdn.datatables.net/select/1.3.3/js/dataTables.select.min.js"></script>
    <script src="https://cdn.datatables.net/fixedheader/3.1.9/js/dataTables.fixedHeader.min.js"></script>
    <link rel="stylesheet" href="https://cdn.datatables.net/fixedheader/3.1.9/css/fixedHeader.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/select/1.3.3/css/select.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/keytable/2.6.4/css/keyTable.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/1.11.4/css/jquery.dataTables.min.css">
</head>
<body>
<h1>Show Inventory</h1>
<table id = "inventory">
  <thead>
  <tr>
    <th>Slot</th>
    <th>Part</th>
    <th>Description</th>
    <th>PID</th>
    <th>Serial Number</th>   
    <th>Virtual ID</th>
  </tr>
  </thead>
  <tbody>
{%-             for slot in to_parse_inventory %}
{%-                 for part in to_parse_inventory[slot] %}
{%-                     for part_number in to_parse_inventory[slot][part] %}
<tr>
    <td>{{ slot }}</td>
    <td>{{ part_number }}</td>
    <td>{{ to_parse_inventory[slot][part][part_number].descr }}</td>
    <td>{{ to_parse_inventory[slot][part][part_number].pid }}</td>
    <td>{{ to_parse_inventory[slot][part][part_number].sn }}</td>
    <td>{{ to_parse_inventory[slot][part][part_number].vid }}</td>
  </tr>
{%-                     endfor %}
{%-                 endfor %}
{%-             endfor %}
  </tbody>
</table>
<script type = "text/javascript">
  $(document).ready(function(){
    $('#inventory thead tr')
    .clone(true)
    .addClass('filters')
    .appendTo('#inventory thead');

    var table = $('#inventory').DataTable({
        keys: true,
        dom: 'Bfrtip',
        lengthMenu: [
            [ 10, 25, 50, -1 ],
            [ '10 rows', '25 rows', '50 rows', 'Show all' ]
        ],
        buttons: [
        'pageLength','colvis','copy', 'csv', 'excel', 'pdf', 'print'
        ],
        colReorder: true,
        select: true,            
        orderCellsTop: true,
        fixedHeader: true,
        initComplete: function () {
        var api = this.api();

        // For each column
        api
            .columns()
            .eq(0)
            .each(function (colIdx) {
                // Set the header cell to contain the input element
                var cell = $('.filters th').eq(
                    $(api.column(colIdx).header()).index()
                );
                var title = $(cell).text();
                $(cell).html('<input type="text" placeholder="' + title + '" />');

                // On every keypress in this input
                $(
                    'input',
                    $('.filters th').eq($(api.column(colIdx).header()).index())
                )
                    .off('keyup change')
                    .on('keyup change', function (e) {
                        e.stopPropagation();

                        // Get the search value
                        $(this).attr('title', $(this).val());
                        var regexr = '({search})'; //$(this).parents('th').find('select').val();

                        var cursorPosition = this.selectionStart;
                        // Search the column for that value
                        api
                            .column(colIdx)
                            .search(
                                this.value != ''
                                    ? regexr.replace('{search}', '(((' + this.value + ')))')
                                    : '',
                                this.value != '',
                                this.value == ''
                            )
                            .draw();

                        $(this)
                            .focus()[0]
                            .setSelectionRange(cursorPosition, cursorPosition);
                    });
            });
    },
});
});        
</script>
</body></html>
{%-         else %}
# Show Inventory
{%-             for slot in to_parse_inventory %}
{%-                 for part in to_parse_inventory[slot] %}
{%-                     for part_number in to_parse_inventory[slot][part] %}
## {{ slot }}
### Part Number: {{ part_number }}
#### Description: {{ to_parse_inventory[slot][part][part_number].descr }}
#### Serial Number: {{ to_parse_inventory[slot][part][part_number].sn }}
#### ID
##### Part: {{ to_parse_inventory[slot][part][part_number].pid }}
##### Virual:{{ to_parse_inventory[slot][part][part_number].vid }}
{%-                     endfor %}
{%-                 endfor %}
{%-             endfor %}
{%-         endif %}
{%-     endif %}
{%- endif %}